package domaine;

import java.math.RoundingMode;
import java.text.NumberFormat;

public class CompteBancaire {
    private int numero;// Numéro du compte.
    private double solde;// solde = montant disponible sur le compte.
    private NumberFormat format = null;

    // Constructeur d'un CompteBancaire.
    public CompteBancaire(int numero) {
        this.numero = numero;
        this.solde = 0.0;
    }

    // Méthode qui permet de déposer de l'argent sur le compte.
    public void depose(double montant) throws Exception {
        if(montant > 0.0) {
            solde += montant;// On ajoute la somme déposée au solde.
        } else {
            throw new Exception("Dépôt d'une valeur négative impossible (compte : " + numero + " depot de " + montant + ").");
        }
    }

    // Méthode qui permet de retirer de l'argent sur le compte.
    public void retire(double montant) throws Exception {
        if(montant > 0.0) {
            if(solde >= montant) {
                solde -= montant;// On retranche du solde la somme retirée.
            } else {
                throw new Exception("La banque n'autorise pas de découvert (compte : " + numero +" solde : " + solde + " retrait de " + montant + ").");
            }
        } else {
            throw new Exception("Retrait d'une valeur négative impossible (compte : " + numero + " retrait de " + montant + ").");
        }
    }

    public double solde() {
        return solde;
    }

    public int numero() {
        return numero;
    }

    public String toString() {
        if (format == null) {
            format = NumberFormat.getNumberInstance();
            format.setMinimumIntegerDigits(1);
            format.setMaximumIntegerDigits(4);
            format.setGroupingUsed(false);
            format.setMinimumFractionDigits(2);
            format.setMaximumFractionDigits(2);
            format.setRoundingMode(RoundingMode.HALF_UP);
        }
        return "numero : " + numero + " solde : " + format.format(solde);
    }
}
